#ifndef Acpi_h
#define Acpi_h
// $Id: Acpi.h,v 1.5 2013/10/25 09:39:37 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CustomProcess.h"

#include <QObject>
#include <QProcess>
#include <QHash>


//! battery monitor
namespace ACPI
{

    //! display a set of log entries, allows selection of one
    class Acpi: public QObject
    {

        Q_OBJECT

        public:

        //! constructor
        Acpi( void );

        //! destructor
        virtual ~Acpi( void )
        {}

        //! battery state
        enum State
        {
            Unknown,
            Charged,
            Charging,
            Discharging
        };

        //! battery level
        enum Level
        {
            Normal,
            Low,
            Critical
        };

        //! battery state
        State state( void ) const
        { return state_; }

        //! battery level
        Level level( void ) const
        { return level_; }

        //! state text
        const QString& stateText( void ) const
        { return stateText_; }

        //! tooltip text
        const QString& tooltipText( void ) const
        { return tooltipText_; }

        //! progress
        int progress( void ) const
        { return progress_; }

        //! threshold
        void setThreshold( Level level, int value )
        { thresholds_[level] = value; }

        Q_SIGNALS:

        void updated( void );

        public Q_SLOTS:

        //! update all dataSamples from file
        void update( void );

        protected Q_SLOTS:

        //! update
        void _commandCompleted( int, QProcess::ExitStatus status );

        protected:

        //! battery state
        bool _setState( State value, bool forced = false )
        {
            if( value == state_ && !forced ) return false;
            state_ = value;
            return true;
        }

        //! battery level
        bool _setLevel( Level value , bool forced = false )
        {
            if( value == level_ && !forced ) return false;
            level_ = value;
            return true;
        }

        //! progress
        bool _setProgress( int value, bool forced = false )
        {
            if( value == progress_ && !forced ) return false;
            progress_ = value;
            return true;
        }

        private:

        //! process
        CustomProcess process_;

        //! current state
        State state_;

        //! current level
        Level level_;

        //! progress
        int progress_;

        //! state text
        QString stateText_;

        //! tooltip
        QString tooltipText_;

        // threshold
        typedef QHash< Level, int > ThresholdMap;
        ThresholdMap thresholds_;

    };

}

#endif
