#ifndef CalendarEventModel_h
#define CalendarEventModel_h

// $Id: CalendarEventModel.h,v 1.7 2013/04/29 18:27:15 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

/*!
\file CalendarEventModel.h
\brief calendar events
\author Hugo Pereira
\version $Revision: 1.7 $
\date $Date: 2013/04/29 18:27:15 $
*/

#include "CalendarEvent.h"
#include "ListModel.h"

namespace CALENDAR
{

    //! model
    class CalendarEventModel: public ListModel<CalendarEvent>, public Counter
    {

        Q_OBJECT

        public:

        //! number of columns
        enum { nColumns = 1 };

        //! column type enumeration
        enum ColumnType { EVENT };

        //! constructor
        CalendarEventModel( QObject* parent = 0 ):
            ListModel<CalendarEvent>( parent ),
            Counter( "LogbookStatisticsDialog::Model" )
        {}

        //!@name methods reimplemented from base class
        //@{

        //! flags
        virtual Qt::ItemFlags flags(const QModelIndex &index) const
        {
            if( !get( index ).hasFlag( CalendarEvent::Valid ) ) return Qt::ItemIsSelectable;
            else return Qt::ItemIsEnabled |  Qt::ItemIsSelectable;
        }

        //! return data
        virtual QVariant data(const QModelIndex &index, int role) const;

        //! header data
        virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;

        //! number of columns for a given index
        virtual int columnCount(const QModelIndex &parent = QModelIndex()) const
        { return nColumns; }

        //@}

        protected:

        //! sort
        virtual void _sort( int, Qt::SortOrder = Qt::AscendingOrder );

        private:

        //! column names
        static const QString columnNames_[nColumns];

    };

}

#endif
