#ifndef _CalendarPath_h_
#define _CalendarPath_h_
// $Id: CalendarPath.h,v 1.4 2013/04/29 18:27:15 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

/*!
\file    CalendarPath.h
\brief   simple cell-path in calendar
\author  Hugo Pereira
\version $Revision: 1.4 $
\date    $Date: 2013/04/29 18:27:15 $
*/

#include "Counter.h"

#include <QBrush>
#include <QPainterPath>
#include <QPen>
#include <QPolygonF>

#include <QList>

namespace CALENDAR
{
    //! local path
    class Path: public QPainterPath, public Counter
    {
        public:

        //! constructor
        Path( const QPainterPath& path ):
            QPainterPath( path ),
            Counter( "Path" )
        {}

        //! constructor
        Path( const QPolygonF& );

        //! pen
        void setPen( QPen pen )
        { pen_ = pen; }

        //! brush
        const QPen& pen( void ) const
        { return pen_; }

        //! brush
        void setBrush( QBrush brush )
        { brush_ = brush; }

        //! brush
        const QBrush& brush( void ) const
        { return brush_; }

        //! shortcut to PainterPath list
        typedef QList<Path> List;

        private:

        //! pen
        QPen pen_;

        //! brush
        QBrush brush_;

    };
}

#endif
