#ifndef SmtpClient_h
#define SmtpClient_h
// $Id: SmtpClient.h,v 1.6 2013/10/25 09:39:38 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QTcpSocket>
#include <QString>
#include <QTextStream>

//! simple smtp interface
namespace CALENDAR
{
    class SmtpClient : public QObject, public Counter
    {
        Q_OBJECT


        public:

        //! constructor
        SmtpClient( QObject* = 0 );

        //! destructor
        virtual ~SmtpClient()
        {}

        //! set host
        virtual void setHost( const QString&, int = 25 );

        //! send mail
        virtual void send( const QString& sender, const QString& recipient, const QString& subject, const QString& body = QString() );

        protected Q_SLOTS:

        //! server state changed
        virtual void _stateChanged( QAbstractSocket::SocketState );

        //! server error
        virtual void _errorReceived( QAbstractSocket::SocketError );

        //! connected to server
        virtual void _connected();

        //! disconnected from server
        virtual void _disconnected( void );

        //! ready to read
        virtual void _readyRead();

        protected:

        //! message has been sent
        virtual void _messageSent( void );

        //! socket
        const QTcpSocket& _socket( void ) const
        { return socket_; }

        private:

        //! host
        QString host_;

        //! port
        int port_;

        //! message to send
        QString message_;

        //! socket
        QTcpSocket socket_;

        //! streamer
        QTextStream stream_;

        //! sender
        QString sender_;

        //!
        QString recipient_;

        //!
        QString response_;

        //! state
        enum State
        {
            Rcpt,
            Mail,
            Data,
            Init,
            Body,
            Quit,
            Close
        };

        //! state
        State state_;

    };

}
#endif
