
// $Id: ClockConfigurationDialog.cpp,v 1.29 2014/01/10 12:14:16 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ClockConfigurationDialog.h"
#include "ClockConfigurationDialog.moc"

#include "GridLayout.h"
#include "IconEngine.h"
#include "Icons.h"
#include "OptionCheckBox.h"
#include "OptionColorDisplay.h"
#include "OptionSpinBox.h"
#include "OptionBrowsedLineEditor.h"

#include <QGroupBox>
#include <QLabel>
#include <QLayout>

namespace CLOCK
{

    //_________________________________________________________
    ClockConfigurationDialog::ClockConfigurationDialog( QWidget* parent ):
        ConfigurationDialog( parent )
    {

        Debug::Throw( "ClockConfigurationDialog::ClockConfigurationDialog.\n" );
        setWindowTitle( tr( "Configuration - Transparent Clock" ) );

        // generic widgets
        QWidget* page;
        QWidget *box;
        OptionColorDisplay *colorDisplay;
        OptionCheckBox* checkbox;
        OptionSpinBox* spinbox;

        page = &addPage( IconEngine::get( ICONS::PREFERENCE_APPEARANCE), tr( "Appearance" ), tr( "Window appearance and colors" ) );
        page->layout()->addWidget( box = new QGroupBox( tr( "Colors" ), page ));

        QVBoxLayout* vLayout = new QVBoxLayout();
        vLayout->setSpacing(5);
        vLayout->setMargin(5);
        box->setLayout( vLayout );

        // use default colors
        vLayout->addWidget( checkbox = new OptionCheckBox( tr( "Use default colors" ), box, "USE_DEFAULT_COLORS" ) );
        addOptionWidget( checkbox );

        box = new QWidget( box );
        vLayout->addWidget( box );

        GridLayout* gridLayout = new GridLayout();
        gridLayout->setSpacing(5);
        gridLayout->setMargin(0);
        gridLayout->setMaxCount( 2 );
        gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
        box->setLayout( gridLayout );
        connect( checkbox, SIGNAL(toggled(bool)), box, SLOT(setDisabled(bool)) );

        // color widgets
        gridLayout->addWidget( new QLabel( tr( "Hours:" ), box ) );
        gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "HOUR_COLOR" ) );
        addOptionWidget( colorDisplay );

        gridLayout->addWidget( new QLabel( tr( "Minutes:" ), box ) );
        gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "MINUTE_COLOR" ) );
        addOptionWidget( colorDisplay );

        gridLayout->addWidget( new QLabel( tr( "Seconds:" ), box ) );
        gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "SECOND_COLOR" ) );
        addOptionWidget( colorDisplay );

        page->layout()->addWidget( box = new QGroupBox( tr( "Options" ), page ));
        QVBoxLayout* boxLayout( new QVBoxLayout() );
        boxLayout->setSpacing(5);
        boxLayout->setMargin(5);
        box->setLayout( boxLayout );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Show ticks (hours)" ), box, "SHOW_HOUR_TICKS" ) );
        checkbox->setToolTip( tr( "Show/hide clock hours ticks" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Show ticks (minutes)" ), box, "SHOW_MINUTE_TICKS" ) );
        checkbox->setToolTip( tr( "Show/hide clock minutes ticks" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Show date" ), box, "SHOW_DATE" ) );
        checkbox->setToolTip( tr( "Show/hide date" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Show seconds" ), box, "SHOW_SECONDS" ) );
        checkbox->setToolTip( tr( "Show/hide clock ticks" ) );
        addOptionWidget( checkbox );

        page->layout()->addWidget( box = new QGroupBox( tr( "Time Settings" ), page ));
        gridLayout = new GridLayout();
        gridLayout->setSpacing(5);
        gridLayout->setMargin(5);
        gridLayout->setMaxCount( 2 );
        gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
        box->setLayout( gridLayout );

        QLabel* label;
        gridLayout->addWidget( label = new QLabel( tr( "Offset:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "CLOCK_DELAY" ) );
        spinbox->setSuffix( tr( "h" ) );
        spinbox->setMinimum( -24 );
        spinbox->setMaximum( 24 );
        addOptionWidget( spinbox );
        label->setBuddy( spinbox );
        spinbox->setToolTip( tr( "Add hours delay with respect to system time" ) );

        gridLayout->addWidget( label = new QLabel( tr( "Time adjustment application:" ), box ) );
        OptionBrowsedLineEditor* editor = new OptionBrowsedLineEditor( box, "ADJUST_TIME_CMD" );
        gridLayout->addWidget( editor );
        addOptionWidget( editor );
        label->setBuddy( editor );
        editor->setToolTip( tr( "Command used to change time settings" ) );

        read();
    }
}
