
// $Id: DiskConfigurationDialog.cpp,v 1.29 2014/01/10 12:14:16 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "DiskConfigurationDialog.h"
#include "DiskConfigurationDialog.moc"

#include "GridLayout.h"
#include "IconEngine.h"
#include "Icons.h"
#include "OptionCheckBox.h"
#include "OptionColorDisplay.h"
#include "OptionComboBox.h"
#include "OptionSlider.h"
#include "OptionSpinBox.h"

#include <QGroupBox>
#include <QLabel>
#include <QLayout>

namespace DISK
{

    //_________________________________________________________
    DiskConfigurationDialog::DiskConfigurationDialog( QWidget* parent ):
        ConfigurationDialog( parent )
    {

        Debug::Throw( "DiskConfigurationDialog::DiskConfigurationDialog.\n" );
        setWindowTitle( tr( "Configuration - Disk Monitor" ) );

        // generic widgets
        QWidget* page;
        QGroupBox *box;
        OptionColorDisplay *colorDisplay;
        OptionCheckBox* checkbox;
        OptionSlider* slider;

        page = &addPage( IconEngine::get( ICONS::PREFERENCE_APPEARANCE), tr( "Appearance", "Window appearance and colors" ) );
        page->layout()->addWidget( box = new QGroupBox( tr( "Colors" ), page ));

        QVBoxLayout* boxLayout( new QVBoxLayout() );
        boxLayout->setSpacing(5);
        boxLayout->setMargin(5);
        box->setLayout( boxLayout );

        GridLayout* gridLayout = new GridLayout();
        gridLayout->setSpacing(5);
        gridLayout->setMargin(0);
        gridLayout->setMaxCount( 2 );
        gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
        boxLayout->addLayout( gridLayout );

        gridLayout->addWidget( new QLabel( tr( "Read:" ), box ) );
        gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "READ_COLOR" ) );
        addOptionWidget( colorDisplay );

        gridLayout->addWidget( new QLabel( tr( "Write:" ), box ) );
        gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "WRITE_COLOR" ) );
        addOptionWidget( colorDisplay );

        // intensity
        gridLayout->addWidget( new QLabel( tr( "Intensity:" ), this ) );
        gridLayout->addWidget( slider = new OptionSlider( this, "TRANSPARENCY_BACKGROUND_INTENSITY" ) );
        slider->setScale( 1.0/2.55 );
        slider->setRange( 0, 100 );
        addOptionWidget( slider );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Use gradient" ), box, "TRANSPARENCY_USE_GRADIENT" ) );
        addOptionWidget( checkbox );

        // display
        page->layout()->addWidget( box = new QGroupBox( tr( "Display" ), page ));
        boxLayout = new QVBoxLayout();
        boxLayout->setSpacing(5);
        boxLayout->setMargin(5);
        box->setLayout( boxLayout );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Hostname" ), box, "SHOW_HOST" ) );
        checkbox->setToolTip( tr( "Show/hide host name" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Load" ), box, "SHOW_LOAD" ) );
        checkbox->setToolTip( tr( "Show/hide disk load percentage" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Read" ), box, "SHOW_READ" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Write" ), box, "SHOW_WRITE" ) );
        addOptionWidget( checkbox );

        // options
        page->layout()->addWidget( box = new QGroupBox( tr( "Options" ), page ));
        boxLayout = new QVBoxLayout();
        boxLayout->setSpacing(5);
        boxLayout->setMargin(5);
        box->setLayout( boxLayout );

        gridLayout = new GridLayout();
        gridLayout->setSpacing(5);
        gridLayout->setMargin(5);
        gridLayout->setMaxCount( 2 );
        boxLayout->addLayout( gridLayout );

        OptionComboBox *combobox;
        gridLayout->addWidget( new QLabel( tr( "Kernel version:" ), box ) );
        gridLayout->addWidget( combobox = new OptionComboBox( box, "KERNEL_VERSION" ) );
        combobox->setUseValue( false );
        combobox->addItem( tr( "2.4" ) );
        combobox->addItem( tr( "2.6 or above" ) );
        combobox->setToolTip( tr( "Linux kernel version" ) );
        addOptionWidget( combobox );

        OptionSpinBox* spinbox;
        gridLayout->addWidget( new QLabel( tr( "Refresh interval:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "REFRESH_RATE" ) );
        spinbox->setSuffix( tr( "s" ) );
        spinbox->setMinimum( 1 );
        spinbox->setToolTip( tr( "Time interval (seconds) between two refresh" ) );
        addOptionWidget( spinbox );

        gridLayout->addWidget( new QLabel( tr( "Number of samples:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "SAMPLES" ) );
        spinbox->setMinimum( 1 );
        spinbox->setToolTip( tr( "Number of samples averaged for each measurement" ) );
        addOptionWidget( spinbox );

        read();

    }

}
