// $Id: DiskId.h,v 1.7 2013/04/29 18:27:15 hupereir Exp $


/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#ifndef __DiskId_h__
#define __DiskId_h__

#include "Counter.h"
#include <QTextStream>

namespace DISK {

  //! disk minor/major number
  class DiskId: public Counter
  {

    public:

    //! constructor
    DiskId( int major = 0, int minor = 0 ):
      Counter( "DiskId" ),
      major_( major ),
      minor_( minor ),
      valid_( false )
    {};

    //! equal to operator
    bool operator == ( const DiskId& id ) const
    { return (major_ == id.major_) &&  (minor_ == id.minor_); }

    //! lower than operator
    bool operator < ( const DiskId& id ) const
    { return ((major_  < id.major_) || ( major_ == id.major_ && minor_ < id.minor_) ); }

    //! load from stream
    friend QTextStream &operator >> ( QTextStream &in, DiskId& id )
    {
      in >> id.major_ >> id.minor_;
      id.valid_ = (in.status() == QTextStream::Ok );
      return in;
    }

    //! set minor number
    bool valid( void ) const
    { return valid_; }

    //! hash
    unsigned int hash( void ) const
    { return major_<<8 | minor_; }

    private:

    //! major number
    int major_;

    //! minor number
    int minor_;

    //! validity
    bool valid_;

  };

}

//! hash
inline unsigned int qHash( const DISK::DiskId& id )
{ return id.hash(); }

#endif
