// $Id: DiskLoad_24.cpp,v 1.21 2013/04/29 18:27:15 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "DiskLoad_24.h"
#include "Debug.h"
#include "File.h"
#include "Str.h"

#include <QFile>
#include <QStringList>
#include <QTextStream>

namespace DISK
{
    //________________________________________________
    DiskLoad_24::DiskLoad_24( void ):
        filename_( "/proc/stat" ),
        partitionFilename_( "/proc/partitions" ),
        devDirectory_( "/dev" )
    {}

    //________________________________________________
    void DiskLoad_24::loadIdMap( void )
    {
        Debug::Throw( "DiskLoad_24::loadIdMap.\n" );

        // open file
        QFile in( partitionFilename_ );
        if( !in.open( QIODevice::ReadOnly ) )
        {
            Debug::Throw( "DiskLoad_24::loadIdMap - cannot open file.\n" );
            return;
        }


        QStringList lines( QString(in.readAll()).split( "\n" ) );
        for( QStringList::iterator iter = lines.begin(); iter != lines.end(); ++iter )
        {
            int major = 0;
            int minor = 0;
            int blocks = 0;
            QString device("");
            QTextStream stream( &*iter);
            stream >> major >> minor >> blocks >> device;

            if( stream.status() == QTextStream::Ok )
            {

                // try load shorter name from /dev directory
                device = _device( device );

                // create disk id
                DiskId id( major, minor );

                // add to map
                if( _sampleMap().find( id ) != _sampleMap().end() )
                { _diskIds()[device] = DiskId( major, minor ); }

            }
        }

        return;

    }

    //________________________________________________
    void DiskLoad_24::update( void )
    {
        Debug::Throw( "DiskLoad_24::Update.\n" );

        // open file
        QFile in( filename_ );
        if( !in.open( QIODevice::ReadOnly ) )
        {
            Debug::Throw( "DiskLoad_24::update - cannot open file.\n" );
            return;
        }


        QStringList lines( QString( in.readAll() ).split( "\n" ) );
        for( QStringList::iterator iter = lines.begin(); iter != lines.end(); ++iter )
        {
            QString line( *iter );
            if( line.indexOf( "disk_io" ) < 0 ) continue;

            // list of characters to convert into space character
            line.replace( QRegExp( ":|\\(|\\)|," ), " " );
            QTextStream stream( &line );
            QString key;
            stream >> key;
            DiskId id;
            Data data;
            do {
                stream >> id;
                if( id.valid() )
                {

                    unsigned long rw_request, r_request, r_blocks, w_request, w_blocks;
                    stream
                        >> rw_request
                        >> r_request >> r_blocks
                        >> w_request >> w_blocks;

                    data = Data( r_blocks, w_blocks );
                    data.setTime( _timer().elapsed()/1000 );
                    data.setValid( stream.status() == QTextStream::Ok );

                    if( data.valid() )
                    {

                        if( _sampleMap().find( id ) == _sampleMap().end() )
                        {
                            _sampleMap()[ id ].setSampleSize( _sampleSize() );
                            _sampleMap()[ id ].setDataSize( _dataSize() );

                            // refresh ID map to find matching device
                            loadIdMap();

                        }

                        _sampleMap()[id].add( data );
                    }

                }

            } while (id.valid() && data.valid() );

        }

        return;

    }

    //________________________________________________
    QString DiskLoad_24::_device( const QString& device )
    {

        // this should be revisited using QFileInfo
        File::List files( File( devDirectory_ ).listFiles( File::Recursive ) );
        for( File::List::iterator iter = files.begin(); iter != files.end(); ++iter )
        {

            QString link( iter->readLink() );
            if( device == link )
            { return iter->replace( devDirectory_+"/", "" ); }

        }

        return device;

    }
}
