#ifndef Application_h
#define Application_h

// $Id: Application.h,v 1.35 2014/01/12 18:36:25 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ApplicationType.h"
#include "BaseApplication.h"
#include "CommandLineArguments.h"
#include "CommandLineParser.h"
#include "Counter.h"

class TransparentWindow;

//! application
class Application: public BaseApplication, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    Application( CommandLineArguments );

    //! destructor
    ~Application( void );

    //! application type
    virtual void setApplicationType( ApplicationType type )
    { type_ = type; }

    //! create all widgets
    virtual bool realizeWidget( void );

    //! main window
    void setMainWindow( TransparentWindow& top )
    {
        Q_ASSERT( !mainWindow_ );
        mainWindow_ = &top;
    }

    //! main window
    void setMainWindow( TransparentWindow* top )
    {
        Q_ASSERT( !mainWindow_ );
        mainWindow_ = top;
    }

    //! main window
    bool hasMainWindow( void ) const
    { return (bool)mainWindow_; }

    //! main window
    TransparentWindow& mainWindow( void ) const
    {
        Q_CHECK_PTR( mainWindow_ );
        return *mainWindow_;
    }

    //!@name application information
    //@{

    //! command line help
    void usage( void ) const;

    //! application name
    virtual QString applicationName( void ) const;

    //! application icon
    virtual QIcon applicationIcon( void ) const
    { return type_.icon(); }

    // application version
    virtual QString applicationVersion( void ) const;

    // build time stamp
    virtual QString buildTimeStamp( void ) const;

    //@}

    Q_SIGNALS:

    //! option recieved
    void optionRecieved( XmlOption );

    public Q_SLOTS:

    //! geometry
    void sendGeometry( QRect );

    //! geometry
    void sendGeometry( QRect, int );

    //! geometry
    void sendOption( XmlOption option );

    //! Send request to all transparency application for raise
    void sendRaiseRequest( void );

    //! Send request to all transparency application for raise
    void sendCloseRequest( void );

    protected Q_SLOTS:

    //! process request from application manager
    virtual bool _processCommand( SERVER::ServerCommand );

    void _configuration( void )
    {}

    protected:

    //! application type
    const ApplicationType& _type( void ) const
    { return type_; }

    private:

    //! request
    void _sendRequest( SERVER::ServerCommand::CommandType );

    //! broadcast
    void _broadCast( SERVER::ServerCommand );

    //! top widget
    TransparentWindow *mainWindow_;

    //! type
    ApplicationType type_;

};

#endif
