#ifndef ApplicationDataModel_h
#define ApplicationDataModel_h

// $Id: ApplicationDataModel.h,v 1.8 2013/11/19 11:12:14 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "ListModel.h"
#include "ApplicationData.h"

#include <QMimeData>

//! Job model. Stores job information for display in lists
class ApplicationDataModel : public ListModel<ApplicationData>, public Counter
{

    Q_OBJECT

    public:

    //! constructor
    ApplicationDataModel( QObject* = 0 );

    //! destructor
    virtual ~ApplicationDataModel( void )
    {}

    //! number of columns
    enum { nColumns = 3 };

    //! column type enumeration
    enum ColumnType
    {
        Name,
        Position,
        Size
    };

    //!@name methods reimplemented from base class
    //@{

    //! flags
    virtual Qt::ItemFlags flags( const QModelIndex& ) const;

    //! data
    virtual QVariant data( const QModelIndex&, int ) const;

    //! header data
    virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const;

    //! number of columns for a given index
    virtual int columnCount( const QModelIndex& = QModelIndex() ) const
    { return nColumns; }


    //! mime type
    virtual QStringList mimeTypes( void ) const;

    //! mime data
    virtual QMimeData* mimeData( const QModelIndexList& ) const;

    //! drop mine data
    virtual bool dropMimeData(const QMimeData*, Qt::DropAction, int, int, const QModelIndex&);

    //@}

    Q_SIGNALS:

    //! emitted via drag and drop
    void itemOrderChanged( int, int );

    protected:

    //! sort
    virtual void _sort( int, Qt::SortOrder = Qt::AscendingOrder )
    {}

    private:

    //! list column names
    static const QString columnTitles_[nColumns];

};

#endif
