// $Id: ApplicationType.cpp,v 1.12 2014/01/10 15:10:31 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/


#include "ApplicationType.h"

//____________________________________________
ApplicationType::Map& ApplicationType::names( void )
{
  static Map map;
  if( map.empty() )
  {
    map.insert( APP_NONE, QObject::tr( "unknown" ) );
    map.insert( APP_ACPI, QObject::tr( "Battery Monitor" ) );
    map.insert( APP_CALENDAR, QObject::tr( "Transparent Calendar" ) );
    map.insert( APP_CLOCK, QObject::tr( "Transparent Clock" ) );
    map.insert( APP_CPULOAD, QObject::tr( "Cpu Monitor" ) );
    map.insert( APP_DISKLOAD, QObject::tr( "Disk Monitor" ) );
    map.insert( APP_MEMORYLOAD, QObject::tr( "Memory Monitor" ) );
    map.insert( APP_NETWORKLOAD, QObject::tr( "Network Monitor" ) );
    map.insert( APP_SUMMARY, QObject::tr( "System Monitor Summary" ) );
    map.insert( APP_TEMPERATURE, QObject::tr( "Temperature Monitor" ) );

  }
  return map;

}

//____________________________________________
ApplicationType::Map& ApplicationType::iconNames( void )
{
  static Map map;
  if( map.empty() )
  {
    map.insert( APP_NONE, ":/transparency.png");
    map.insert( APP_ACPI, ":transparent-acpi.png");
    map.insert( APP_CALENDAR, ":/transparent-calendar.png");
    map.insert( APP_CLOCK, ":/transparent-clock.png");
    map.insert( APP_CPULOAD, ":/transparent-cpu-load.png");
    map.insert( APP_DISKLOAD, ":/transparent-disk-load.png");
    map.insert( APP_MEMORYLOAD, ":/transparent-memory-load.png");
    map.insert( APP_NETWORKLOAD, ":/transparent-network-load.png");
    map.insert( APP_SUMMARY, ":/transparent-system-monitor.png");
    map.insert( APP_TEMPERATURE, ":/transparency.png");

  }
  return map;

}

//____________________________________________
ApplicationType::Set::Set( const CommandLineParser& parser )
{

    bool all( parser.hasFlag( "--all" ) );
    if( all || parser.hasFlag( "--acpi" ) ) insert( ApplicationType::APP_ACPI );
    if( all || parser.hasFlag( "--calendar" ) ) insert( ApplicationType::APP_CALENDAR );
    if( all || parser.hasFlag( "--clock" ) ) insert( ApplicationType::APP_CLOCK );
    if( all || parser.hasFlag( "--cpu" ) ) insert( ApplicationType::APP_CPULOAD );
    if( all || parser.hasFlag( "--disk" ) ) insert( ApplicationType::APP_DISKLOAD );
    if( all || parser.hasFlag( "--memory" ) ) insert( ApplicationType::APP_MEMORYLOAD );
    if( all || parser.hasFlag( "--network" ) ) insert( ApplicationType::APP_NETWORKLOAD );
    if( all || parser.hasFlag( "--summary" ) ) insert( ApplicationType::APP_SUMMARY );
    if( all || parser.hasFlag( "--temperature" ) ) insert( ApplicationType::APP_TEMPERATURE );

}

//____________________________________________
ApplicationType::Set::Set( unsigned int mask )
{
    if( mask & APP_ACPI ) insert( ApplicationType::APP_ACPI );
    if( mask & APP_CALENDAR ) insert( ApplicationType::APP_CALENDAR );
    if( mask & APP_CLOCK ) insert( ApplicationType::APP_CLOCK );
    if( mask & APP_CPULOAD ) insert( ApplicationType::APP_CPULOAD );
    if( mask & APP_DISKLOAD ) insert( ApplicationType::APP_DISKLOAD );
    if( mask & APP_MEMORYLOAD ) insert( ApplicationType::APP_MEMORYLOAD );
    if( mask & APP_NETWORKLOAD ) insert( ApplicationType::APP_NETWORKLOAD );
    if( mask & APP_SUMMARY ) insert( ApplicationType::APP_SUMMARY );
    if( mask & APP_TEMPERATURE ) insert( ApplicationType::APP_TEMPERATURE );

}

//______________________________________
ApplicationType::Set::operator unsigned int () const
{
    unsigned int out( ApplicationType::APP_NONE );
    for( const_iterator iter = begin(); iter != end(); ++iter )
    { out |= iter->type(); }

    return out;
}
