#ifndef _ApplicationType_h_
#define _ApplicationType_h_

// $Id: ApplicationType.h,v 1.9 2014/01/10 15:10:31 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CommandLineParser.h"
#include "Counter.h"
#include "IconEngine.h"

#include <QHash>
#include <QIcon>
#include <QSet>
#include <QString>

class ApplicationType:public Counter
{

    public:

    //! application enumeration
    enum Type
    {
        APP_NONE = 0,
        APP_ACPI = 1<<0,
        APP_CALENDAR = 1<<1,
        APP_CLOCK = 1<<2,
        APP_CPULOAD = 1<<3,
        APP_DISKLOAD = 1<<4,
        APP_MEMORYLOAD = 1<<5,
        APP_NETWORKLOAD = 1<<6,
        APP_SUMMARY = 1<<7,
        APP_TEMPERATURE = 1<<8

    };


    //! application map
    class Set: public QSet<ApplicationType>
    {

        public:

        //! default constructor
        Set( void )
        {}

        //! constructor from command line
        Set( const CommandLineParser& );

        //! constructor from mask
        Set( unsigned int );

        //! destructor
        virtual ~Set( void )
        {}

        //! cast to mask
        operator unsigned int () const;

    };

    //! constructor
    ApplicationType( const Type& type ):
        Counter( "ApplicationType" ),
        type_( type )
    {}

    //! equal to
    bool operator == ( const ApplicationType& other ) const
    { return type_ == other.type_; }

    //! less than
    bool operator < ( const ApplicationType& other ) const
    { return type_ < other.type_; }

    //! type
    const Type& type( void ) const
    { return type_; }

    //! application title
    QString name( void ) const
    { return names()[type_]; }

    //! application icon
    QString iconName( void ) const
    { return iconNames()[type_]; }

    //! application icon
    QIcon icon( void ) const
    { return IconEngine::get( iconName() ); }

    //! application map
    typedef QHash<Type, QString > Map;

    //! map application names and type
    static Map& names();

    //! icon map
    static Map& iconNames();

    private:

    //! type
    Type type_;

};

inline unsigned int qHash( const ApplicationType& type )
{ return qHash( type.type() ); }

#endif
