#ifndef GeometryApplication_h
#define GeometryApplication_h

// $Id: GeometryApplication.h,v 1.12 2014/01/12 18:36:25 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ApplicationData.h"
#include "BaseApplication.h"
#include "CommandLineArguments.h"
#include "Config.h"
#include "Counter.h"
#include "IconEngine.h"

class GeometryDialog;

//! Main Window singleton object
class GeometryApplication: public BaseApplication, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    GeometryApplication( CommandLineArguments );

    //! destructor
    ~GeometryApplication( void );

    //! create all widgets
    bool realizeWidget( void );

    //! cvs log frame
    GeometryDialog& mainWindow( void ) const
    { return *mainWindow_; }

    //!@name application information
    //@{

    //! usage
    void usage( void ) const;

    //! application name
    virtual QString applicationName( void ) const
    { return "Transparency-settings"; }

    //! application icon
    virtual QIcon applicationIcon( void ) const
    { return IconEngine::get( ":/transparency.png" ); }

    // application version
    virtual QString applicationVersion( void ) const
    { return VERSION; }

    // build time stamp
    virtual QString buildTimeStamp( void ) const
    { return BUILD_TIMESTAMP; }

    //@}

    protected Q_SLOTS:

    //! Send request to all transparency application for raise
    void _sendGeometryRequest( void );

    //! send geometry
    void _sendGeometry( ApplicationData );

    //! configuration
    void _configuration( void );

    //! command
    virtual bool _processCommand( SERVER::ServerCommand command );

    private:

    //! request
    void _sendRequest( SERVER::ServerCommand::CommandType );

    //! cvs log display frame
    GeometryDialog *mainWindow_;

};

#endif
