#ifndef GeometryDialog_h
#define GeometryDialog_h

// $Id: GeometryDialog.h,v 1.15 2013/12/19 12:56:28 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ApplicationDataModel.h"
#include "CustomDialog.h"
#include "OptionAnchorWidget.h"
#include "OptionComboBox.h"
#include "OptionSpinBox.h"
#include "OptionWidgetList.h"

#include <QPushButton>

class TreeView;

//! list transparency applications geometry
class GeometryDialog: public CustomDialog, public OptionWidgetList
{

    //! Qt meta object declaration
    Q_OBJECT;

    public:

    //! constructor
    GeometryDialog( QWidget* = 0 );

    //! application data
    void add( ApplicationData );

    Q_SIGNALS:

    //! modified
    void modified( void );

    //! geometry requested
    void geometryRequested( void );

    //! geometry changed
    void geometryChanged( ApplicationData );

    public Q_SLOTS:

    //! reload document classes
    void reload( void );

    protected Q_SLOTS:

    //! update buttons
    void _updateButtons( void );

    //! edit
    void _edit( void );

    //! apply
    void _apply( bool = true );

    //! apply
    void _applyUnchecked( void )
    { _apply( false ); }

    //! restore default
    void _restoreDefaults( void );

    //! move up selected task
    void _up( void );

    //! move down selected task
    void _down( void );

    //! reorder
    void _reorder( int, int );

    //! sort
    void _sort( int );

    //! sort
    void _sort( void );

    private Q_SLOTS:

    //! configuration
    void _updateConfiguration( void );

    //! configuration
    void _saveConfiguration( void );

    private:

    //! model
    ApplicationDataModel model_;

    //! backup
    ApplicationDataModel::List backup_;

    //! document classes list
    TreeView* list_;

    //! edit
    QPushButton* edit_;

    //! move up
    QPushButton* up_;

    //! move down
    QPushButton* down_;

    //! reload
    QPushButton* reload_;

    //!@name reorganization configuration
    //@{

    //! alignment
    OptionComboBox* alignmentComboBox_;

    //! anchor
    OptionAnchorWidget* anchorWidget_;

    //! offset
    OptionSpinBox* offsetSpinBox_;

    //! spacing
    OptionSpinBox* spacingSpinBox_;

    //! apply button
    QPushButton* apply_;

    //@}

};

#endif
