// $Id: run.cpp,v 1.21 2014/01/12 18:36:25 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TransparencyApplication.h"
#include "ErrorHandler.h"

#include "DefaultOptions.h"
#include "Singleton.h"
#include "SvgDefaultOptions.h"
#include "TransparencyDefaultOptions.h"
#include "X11Util.h"

#include <signal.h>
#include <QApplication>

//_______________________________
//! handles keyboard interruptions
void interrupt( int sig );

//__________________________________________
//! main function
int run( ApplicationType type, int argc, char *argv[] )
{

    // Ensure proper cleaning at exit
    signal(SIGINT,  interrupt);
    signal(SIGTERM, interrupt);

    // install error handler
    ErrorHandler::initialize();

    Q_INIT_RESOURCE( basePixmaps );
    Q_INIT_RESOURCE( pixmaps );
    Q_INIT_RESOURCE( baseSvg );

    installDefaultOptions();
    installSvgOptions();
    installTransparencyOptions();

    // create Application
    QApplication application( argc, argv );

    TransparencyApplication singleton( CommandLineArguments( argc, argv ) );
    Singleton::get().setApplication( &singleton );
    singleton.setApplicationType( type );

    // initialize and run
    if( singleton.initApplicationManager() )
    {  application.exec(); }

    return 0;

}

//_____________________________________________
void interrupt( int sig )
{
    Debug::Throw() << "interrupt - Recieved signal " << sig << endl;
    qApp->quit();
}
