// $Id: transparent-clock.cpp,v 1.32 2014/01/12 18:36:25 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ClockOptions.h"

#include "Application.h"
#include "ClockWidget.h"
#include "ClockXmlDef.h"
#include "DefaultOptions.h"
#include "ErrorHandler.h"
#include "Singleton.h"
#include "SvgDefaultOptions.h"
#include "TransparencyDefaultOptions.h"
#include "XmlMigration.h"
#include "XmlOptions.h"
#include "X11Util.h"

#include <QApplication>
#include <signal.h>

//_______________________________
//! handles keyboard interruptions
void interrupt( int sig );

//__________________________________________
//! main function
int main(int argc, char *argv[])
{

    // Ensure proper cleaning at exit
    signal(SIGINT,  interrupt);
    signal(SIGTERM, interrupt);

    // install error handler
    ErrorHandler::initialize();

    // options
    installDefaultOptions();
    installClockOptions();
    installSvgOptions();
    installTransparencyOptions();

    // customize options
    XmlOptions::setFile( XmlOptions::get().raw( "RC_FILE" ) );
    XmlOptions::read();

    // set debug level
    Debug::setLevel( XmlOptions::get().get<int>( "DEBUG_LEVEL" ) );
    if( Debug::level() ) Debug::Throw() << XmlOptions::get() << endl;

    // migration
    XmlMigration( File(".transparent-clock_db").addPath(Util::home() ), "DB_FILE", CLOCK::XML::ALARM_LIST ).run();

    // resources
    Q_INIT_RESOURCE( basePixmaps );
    Q_INIT_RESOURCE( pixmaps );
    Q_INIT_RESOURCE( baseSvg );

    // create Application
    QApplication application( argc, argv );

    Application singleton( CommandLineArguments( argc, argv ) );
    Singleton::get().setApplication( &singleton );

    singleton.setApplicationType( ApplicationType::APP_CLOCK );
    singleton.setMainWindow( new CLOCK::ClockWidget() );
    singleton.mainWindow().setAttribute( Qt::WA_AlwaysShowToolTips, true );

    // initialize and run
    if( singleton.initApplicationManager() )
    {  application.exec(); }

    return 0;

}

//_____________________________________________
void interrupt( int sig )
{
    Debug::Throw() << "interrupt - Recieved signal " << sig << endl;
    qApp->quit();
}
