// $Id: transparent-pictures.cpp,v 1.35 2014/01/12 18:36:25 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "PictureOptions.h"
#include "DefaultOptions.h"
#include "Debug.h"
#include "ErrorHandler.h"
#include "Singleton.h"
#include "PictureApplication.h"
#include "PictureXmlDef.h"
#include "SvgDefaultOptions.h"
#include "TransparencyDefaultOptions.h"
#include "XmlMigration.h"
#include "X11Util.h"

#include <QApplication>
#include <signal.h>

#if defined(QT_USE_STATIC_PLUGINS)
#include <QtPlugin>
Q_IMPORT_PLUGIN(qgif)
Q_IMPORT_PLUGIN(qjpeg)
Q_IMPORT_PLUGIN(qsvg)
Q_IMPORT_PLUGIN(qtiff)
#endif

//_______________________________
//! to handle keyboard interuptions
void interrupt( int sig );

//__________________________________________
int main (int argc, char *argv[])
{

    // Ensure proper cleaning at exit
    signal(SIGINT,  interrupt);
    signal(SIGTERM, interrupt);

    // install error handler
    ErrorHandler::initialize();

    // load default options
    installDefaultOptions();
    installPictureOptions();
    installSvgOptions();
    installTransparencyOptions();

    // customize options
    XmlOptions::setFile( XmlOptions::get().raw( "RC_FILE" ) );
    XmlOptions::read();

    // debug level
    Debug::setLevel( XmlOptions::get().get<int>("DEBUG_LEVEL") );
    if( Debug::level() ) Debug::Throw() << XmlOptions::get() << endl;

    // xml migration
    XmlMigration( File(".transparent-picture_db").addPath(Util::home() ), "XML_FILE", PICTURES::XML::PICTURE_LIST ).run();

    Q_INIT_RESOURCE( basePixmaps );
    Q_INIT_RESOURCE( pixmaps );
    Q_INIT_RESOURCE( baseSvg );

    // create Application
    QApplication application( argc, argv );

    // the curly brackets here are to make sure the
    // singleton application is deleted before QApplication
    PictureApplication singleton( CommandLineArguments( argc, argv ) );
    Singleton::get().setApplication( &singleton );

    // initialize and run
    if( singleton.initApplicationManager() )
    { application.exec(); }

    return 0;
}

//_____________________________________________
void interrupt( int sig )
{
    Debug::Throw() << "interrupt - Recieved signal " << sig << endl;
    qApp->quit();
}
