
// $Id: MemoryConfigurationDialog.cpp,v 1.28 2014/01/10 12:14:16 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "MemoryConfigurationDialog.h"
#include "MemoryConfigurationDialog.moc"

#include "GridLayout.h"
#include "IconEngine.h"
#include "Icons.h"
#include "OptionCheckBox.h"
#include "OptionColorDisplay.h"
#include "OptionComboBox.h"
#include "OptionSlider.h"
#include "OptionSpinBox.h"

#include <QGroupBox>
#include <QLabel>
#include <QLayout>

namespace MEMORY
{

    //_________________________________________________________
    MemoryConfigurationDialog::MemoryConfigurationDialog( QWidget* parent ):
        ConfigurationDialog( parent )
    {

        Debug::Throw( "MemoryConfigurationDialog::MemoryConfigurationDialog.\n" );
        setWindowTitle( tr( "Configuration - Memory Monitor" ) );

        // generic widgets
        QWidget* page;
        QGroupBox *box;
        OptionColorDisplay *colorDisplay;
        OptionCheckBox* checkbox;
        OptionSlider* slider;

        page = &addPage( IconEngine::get( ICONS::PREFERENCE_APPEARANCE), tr( "Appearance" ), tr( "Window appearance and colors" ) );
        page->layout()->addWidget( box = new QGroupBox( tr( "Colors" ), page ));

        QVBoxLayout* box_layout( new QVBoxLayout() );
        box_layout->setSpacing(5);
        box_layout->setMargin(5);
        box->setLayout( box_layout );

        GridLayout* grid_layout = new GridLayout();
        grid_layout->setSpacing(5);
        grid_layout->setMargin(0);
        grid_layout->setMaxCount( 2 );
        grid_layout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
        box_layout->addLayout( grid_layout );

        grid_layout->addWidget( new QLabel( tr( "Memory:" ), box ) );
        grid_layout->addWidget( colorDisplay = new OptionColorDisplay( box, "MEMORY_COLOR" ) );
        addOptionWidget( colorDisplay );

        grid_layout->addWidget( new QLabel( tr( "Swap:" ), box ) );
        grid_layout->addWidget( colorDisplay = new OptionColorDisplay( box, "SWAP_COLOR" ) );
        addOptionWidget( colorDisplay );

        // intensity
        grid_layout->addWidget( new QLabel( tr( "Intensity:" ), this ) );
        grid_layout->addWidget( slider = new OptionSlider( this, "TRANSPARENCY_BACKGROUND_INTENSITY" ) );
        slider->setScale( 1.0/2.55 );
        slider->setRange( 0, 100 );
        addOptionWidget( slider );

        box_layout->addWidget( checkbox = new OptionCheckBox( tr( "Use gradient" ), box, "TRANSPARENCY_USE_GRADIENT" ) );
        addOptionWidget( checkbox );

        // display
        page->layout()->addWidget( box = new QGroupBox( tr( "Display" ), page ));
        box_layout = new QVBoxLayout();
        box_layout->setSpacing(5);
        box_layout->setMargin(5);
        box->setLayout( box_layout );

        box_layout->addWidget( checkbox = new OptionCheckBox(  tr( "Hostname" ), box, "SHOW_HOST" ) );
        checkbox->setToolTip( tr( "Show/hide host name" ) );
        addOptionWidget( checkbox );

        box_layout->addWidget( checkbox = new OptionCheckBox( tr( "Load" ), box, "SHOW_LOAD" ) );
        checkbox->setToolTip( tr( "Show/hide memory load percentage" ) );
        addOptionWidget( checkbox );

        box_layout->addWidget( checkbox = new OptionCheckBox( tr( "Memory" ), box, "SHOW_MEMORY" ) );
        addOptionWidget( checkbox );

        box_layout->addWidget( checkbox = new OptionCheckBox( tr( "Swap" ), box, "SHOW_SWAP" ) );
        addOptionWidget( checkbox );

        // options
        page->layout()->addWidget( box = new QGroupBox( tr( "Options" ), page ));
        box_layout = new QVBoxLayout();
        box_layout->setSpacing(5);
        box_layout->setMargin(5);
        box->setLayout( box_layout );

        grid_layout = new GridLayout();
        grid_layout->setSpacing(5);
        grid_layout->setMargin(5);
        grid_layout->setMaxCount( 2 );
        box_layout->addLayout( grid_layout );

        OptionComboBox *combobox;
        grid_layout->addWidget( new QLabel( tr( "Kernel version:" ), box ) );
        grid_layout->addWidget( combobox = new OptionComboBox( box, "KERNEL_VERSION" ) );
        combobox->setUseValue( false );
        combobox->addItem( tr( "2.4" ) );
        combobox->addItem( tr( "2.6 or above" ) );
        combobox->setToolTip( tr( "Linux kernel version" ) );
        addOptionWidget( combobox );

        OptionSpinBox* spinbox;
        grid_layout->addWidget( new QLabel( tr( "Refresh interval:" ), box ) );
        grid_layout->addWidget( spinbox = new OptionSpinBox( box, "REFRESH_RATE" ) );
        spinbox->setSuffix( tr( "s" ) );
        spinbox->setMinimum( 1 );
        spinbox->setToolTip( tr( "Time interval (seconds) between two refresh" ) );
        addOptionWidget( spinbox );

        grid_layout->addWidget( new QLabel( tr( "Number of samples:" ), box ) );
        grid_layout->addWidget( spinbox = new OptionSpinBox( box, "SAMPLES" ) );
        spinbox->setMinimum( 1 );
        spinbox->setToolTip( tr( "Number of samples averaged for each measurement" ) );
        addOptionWidget( spinbox );

        box_layout->addWidget( checkbox = new OptionCheckBox( tr( "Auto-scale" ), box, "AUTO_SCALE" ) );
        checkbox->setToolTip( tr( "Adjust scale automatically to match the maximum load on display" ) );
        addOptionWidget( checkbox );

        read();

    }
}
