#ifndef _MemoryWidget_h_
#define _MemoryWidget_h_

// $Id: MemoryWidget.h,v 1.23 2013/10/25 09:39:38 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "MemoryLoad.h"
#include "HistogramWidget.h"

#include <QAction>
#include <QActionGroup>
#include <QMap>
#include <QPainter>
#include <QTimerEvent>
#include <QBasicTimer>

//! memory widgets
namespace MEMORY {

    //! transparent memory load widget
    class MemoryWidget : public HistogramWidget
    {

        //! Qt meta object functions
        Q_OBJECT

            public:

            //! constructor
            MemoryWidget( QWidget *parent=0 );

        protected:

        //! context menu
        virtual void _installContextMenuActions( BaseContextMenu* );

        //! tooltip
        virtual bool _updateToolTip( void );

        //!@name actions
        //@{

        //! auto-scale
        QAction& _autoScaleAction( void ) const
        { return *autoScaleAction_; }

        //@}

        //!@name event handlers
        //@{

        //! timer
        void timerEvent( QTimerEvent* );

        //! paint
        void _paint( QPaintDevice&, const QRect& );

        //! resize event [overloaded]
        void resizeEvent( QResizeEvent* );

        //@}

        protected Q_SLOTS:

        //! opend configuration dialog
        virtual void _configuration( void );

        //! update configuration
        virtual void _updateConfiguration( void );

        private Q_SLOTS:

        //! toggle auto scale
        void _toggleAutoScale( bool );

        //! toggle display
        void _toggleDisplay( QAction* );

        protected:

        //! update display actions from mask
        void _updateDisplayActions( void );

        //! scale factor
        double _getScale( const MemoryLoad::DataList& data ) const;

        //! draw load text
        void _paintLoad( QPainter&, QRect& );

        private:

        //! install actions
        void _installActions( void );

        //! memory load probe
        MemoryLoad memoryLoad_;

        //!@name actions
        //@{

        //! auto-scale action
        QAction* autoScaleAction_;

        //! display actions
        QActionGroup* displayActionGroup_;

        //! display actions
        typedef QMap<QAction*, MemoryLoad::DataType> DisplayActionMap;

        //! display actions
        DisplayActionMap displayActions_;

        //@}

        //!@name properties
        //@{

        //! display mask
        unsigned int displayMask_;

        //! color map
        typedef QMap< MemoryLoad::DataType, Color > ColorMap;

        //! color map
        ColorMap colorMap_;

        //@}

    };
}

#endif
