// $Id: PictureAttributes.cpp,v 1.12 2013/04/29 18:27:17 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "PictureAttributes.h"
#include "PictureXmlDef.h"
#include "Str.h"
#include "XmlTimeStamp.h"
#include "XmlString.h"

namespace PICTURES
{

    //_____________________________________________
    const QString PictureAttributes::NO_PICTURE = "none";

    //_____________________________________________
    PictureAttributes::PictureAttributes(  const QDomElement& element ):
        Counter( "PictureAttributes" ),
        filename_( NO_PICTURE ),
        visible_( true )
    {

        Debug::Throw( "PictureAttributes::PictureAttributes.\n" );

        // parse attributes
        QDomNamedNodeMap attributes( element.attributes() );
        for( unsigned int i=0; i<attributes.length(); i++ )
        {
            QDomAttr attribute( attributes.item( i ).toAttr() );
            if( attribute.isNull() ) continue;
            else if( attribute.name() == XML::X ) position_.setX( attribute.value().toInt() );
            else if( attribute.name() == XML::Y ) position_.setY( attribute.value().toInt() );
            else if( attribute.name() == XML::WIDTH ) size_.setWidth( attribute.value().toInt() );
            else if( attribute.name() == XML::HEIGHT ) size_.setHeight( attribute.value().toInt() );
            else if( attribute.name() == XML::FILENAME ) setFilename( XmlString( attribute.value() ).toText() );
            else if( attribute.name() == XML::VISIBILITY ) setVisible( attribute.value().toInt() );
            else Debug::Throw(0) << "PictureAttributes::PictureAttributes - unrecognized entry attribute: \"" << attribute.name() << "\"\n";
        }

    }


    //______________________________________________________________________
    QDomElement PictureAttributes::domElement( QDomDocument& document ) const
    {
        Debug::Throw( "PictureAttributes::domElement.\n" );

        QDomElement out( document.createElement( XML::PICTURE ) );
        out.setAttribute( XML::X, Str().assign<int>( position().x() ) );
        out.setAttribute( XML::Y, Str().assign<int>( position().y() ) );
        out.setAttribute( XML::WIDTH, Str().assign<int>( size().width() ) );
        out.setAttribute( XML::HEIGHT, Str().assign<int>( size().height() ) );
        out.setAttribute( XML::FILENAME, XmlString( filename() ).toXml() );
        out.setAttribute( XML::VISIBILITY, QString().setNum( isVisible() ) );
        return out;
    }

    //____________________________________________________________________
    bool PictureAttributes::operator < (const PictureAttributes& attributes ) const
    {
        if( filename() != attributes.filename() ) return filename() < attributes.filename();
        if( size().width() != attributes.size().width() ) return size().width() < attributes.size().width();
        if( size().height() != attributes.size().height() ) return size().height() < attributes.size().height();
        if( position().x() != attributes.position().x() ) return position().x() < attributes.position().x();
        if( position().y() != attributes.position().y() ) return position().y() < attributes.position().y();
        return false;
    }

    //____________________________________________________________________
    bool PictureAttributes::operator == (const PictureAttributes& attributes ) const
    {
        return
            filename() == attributes.filename() &&
            size() == attributes.size() &&
            position() == attributes.position();
    }

}
