#ifndef _PictureAttributes_h_
#define _PictureAttributes_h_
// $Id: PictureAttributes.h,v 1.9 2013/04/29 18:27:17 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QDomDocument>
#include <QDomElement>
#include <QList>
#include <QPoint>
#include <QSize>

//! clock widgets
namespace PICTURES
{


    //! transparent clock widget
    class PictureAttributes: public Counter
    {

        public:

        //! no picture filename
        static const QString NO_PICTURE;

        //! list of attributes
        typedef QList<PictureAttributes> List;

        //! constructor
        PictureAttributes( const QDomElement& element = QDomElement() );

        //! convert to Xml
        QDomElement domElement( QDomDocument& document ) const;

        //! less than operator
        bool operator < (const PictureAttributes& ) const;

        //! equal to operator
        bool operator == (const PictureAttributes& ) const;

        //! filename
        const QString& filename( void ) const
        { return filename_; }

        //! filename
        bool setFilename( QString file )
        {
            if( filename_ == file ) return false;
            filename_ = file;
            return true;
        }

        const QPoint& position( void ) const
        { return position_; }

        //! position
        bool setPosition( const QPoint& position )
        {
            if( position_ == position ) return false;
            position_ = position;
            return false;
        }

        //! size
        const QSize& size( void ) const
        { return size_; }

        //! size
        bool setSize( const QSize& size )
        {
            if( size_ == size ) return false;
            size_ = size;
            return true;
        }

        //! visibility
        const bool& isVisible( void ) const
        { return visible_; }

        //! visibility
        bool setVisible( const bool& value )
        {
            if( visible_ == value ) return false;
            visible_ = value;
            return true;
        }

        private:

        //! filename
        QString filename_;

        //! position
        QPoint position_;

        //! size
        QSize size_;

        //! visibility
        bool visible_;

    };



};

#endif
