
// $Id: PictureConfigurationDialog.cpp,v 1.19 2014/01/10 12:14:16 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "PictureConfigurationDialog.h"
#include "PictureConfigurationDialog.moc"

#include "GridLayout.h"
#include "IconEngine.h"
#include "Icons.h"
#include "OptionCheckBox.h"
#include "OptionBrowsedLineEditor.h"

#include <QGroupBox>
#include <QLabel>
#include <QLayout>

namespace PICTURES
{

    //_________________________________________________________
    PictureConfigurationDialog::PictureConfigurationDialog( QWidget* parent ):
        ConfigurationDialog( parent )
    {

        Debug::Throw( "PictureConfigurationDialog::PictureConfigurationDialog.\n" );
        setWindowTitle( tr( "Configuration - Picture Viewer" ) );

        // generic widgets
        QWidget* page;
        QGroupBox *box;
        OptionCheckBox* checkbox;

        page = &addPage( IconEngine::get( ICONS::PREFERENCE_APPEARANCE), tr( "Appearance" ), tr( "Window appearance and colors" ) );
        page->layout()->addWidget( box = new QGroupBox( "Colors", page ));

        box->setLayout( new QVBoxLayout() );
        box->layout()->setSpacing(5);
        box->layout()->setMargin(5);

        GridLayout* gridLayout = new GridLayout();
        gridLayout->setSpacing(5);
        gridLayout->setMargin(0);
        gridLayout->setMaxCount( 2 );
        box->layout()->addItem( gridLayout );

        box->layout()->addWidget( checkbox = new OptionCheckBox( tr( "Keep aspect ratio" ), box, "KEEP_ASPECT_RATIO" ) );
        checkbox->setToolTip( tr( "Preserve image aspect ratio" ) );
        addOptionWidget( checkbox );

        box->layout()->addWidget( checkbox = new OptionCheckBox(  tr( "Show filename" ), box, "SHOW_FILENAME" ) );
        checkbox->setToolTip( tr( "Show/hide filename" ) );
        addOptionWidget( checkbox );

        QLabel* label;
        gridLayout->addWidget( label = new QLabel( tr( "Filename;" ), box ) );
        OptionBrowsedLineEditor* editor = new OptionBrowsedLineEditor( box, "PICTURE" );
        gridLayout->addWidget( editor );
        addOptionWidget( editor );
        label->setBuddy( editor );
        editor->setToolTip( tr( "File to be loaded" ) );

        read();

    }

}
