#ifndef PictureListDialog_h
#define PictureListDialog_h

// $Id: PictureListDialog.h,v 1.9 2013/10/25 09:39:38 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

/*!
\file PictureListDialog.h
\brief Edit/create pictures
\author Hugo Pereira
\version $Revision: 1.9 $
\date $Date: 2013/10/25 09:39:38 $
*/

#include "CustomDialog.h"
#include "PictureAttributesModel.h"

#include <QPushButton>
#include <QAction>

class TreeView;

namespace PICTURES
{
    //! Edit/create alarms
    class PictureListDialog: public CustomDialog
    {


        //! Qt meta object declaration
        Q_OBJECT

        public:

        //! constructor
        PictureListDialog( QWidget* parent, const PictureAttributes::List& list = PictureAttributes::List() );

        //! destructor
        virtual ~PictureListDialog( void )
        {}

        //! picture list
        void setAttributes( const PictureAttributes::List& list );

        //! picture list
        PictureAttributes::List attributes( void ) const;

        private Q_SLOTS:

        //! configuration update
        void _updateConfiguration( void );

        //! update buttons
        void _updateButtons( void );

        //! add a value
        void _add( void );

        //! add a value
        void _edit( void );

        //! remove a value
        void _remove( void );

        //! check all
        void _selectAll( void );

        //! uncheck all
        void _selectNone( void );

        //! invert selection
        void _invert( void );

        //! toggle (check/uncheck) item
        void _toggle( const QModelIndex& );

        private:

        //! list
        TreeView& _list( void ) const
        { return *list_; }

        //! model
        PictureAttributesModel& _model( void )
        { return model_; }

        //! model
        const PictureAttributesModel& _model( void ) const
        { return model_; }

        //! model
        PictureAttributesModel model_;

        //! picture list
        TreeView* list_;

        //! edit button
        QPushButton* edit_;

        //! remove button
        QPushButton* remove_;

        //! select all
        QPushButton* selectAllButton_;

        //! deselect
        QPushButton* selectNoneButton_;

        //! invert
        QPushButton* invertButton_;

        //! remove action
        QAction* removeAction_;

    };

}

#endif
