// $Id: SummaryData.cpp,v 1.5 2013/04/29 18:27:17 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "SummaryData.h"
#include "TextFormat.h"

namespace SUMMARY
{

    static const unsigned int spacing( 3 );
    static const unsigned int separator( 4 );

    //_______________________________________________________
    int SummaryData::keyExtend( QPainter& painter ) const
    {
        if( isSeparator_ || key_.isEmpty() ) return 0;
        return painter.boundingRect( QRect(), Qt::AlignLeft|Qt::AlignTop, key_ ).width();
    }

    //_______________________________________________________
    void SummaryData::paint( QPainter& painter, QRect& rect ) const
    {

        if( isSeparator_ )
        {

            rect.setTop( rect.top() + separator );

        } else {

            painter.save();
            const int left( rect.left() );
            rect.setLeft( rect.left() + horizontalOffset_ );

            QRect boundingRect;

            // paint key
            if( !key_.isEmpty() )
            {
                // paint key
                QString buffer( key_ );
                if( !value_.isEmpty() ) buffer += ": ";
                painter.drawText( rect, Qt::AlignLeft|Qt::AlignTop, buffer, &boundingRect );

                // update rect
                rect.setRight( qMax( rect.right(), boundingRect.right() ) );
                rect.setLeft( boundingRect.right() + spacing );
            }

            if( !value_.isEmpty() )
            {

                // paint value
                if( format_ )
                {

                    QFont font( painter.font() );
                    font.setWeight( (format_ & FORMAT::Bold) ?  QFont::Bold:QFont::Normal );
                    font.setItalic( format_ & FORMAT::Italic );
                    font.setUnderline( format_ & FORMAT::Underline );
                    font.setStrikeOut( format_ & FORMAT::Strike);
                    painter.setFont( font );

                }

                if( key_.isEmpty() )
                {

                    painter.drawText( rect, Qt::AlignHCenter|Qt::AlignTop, value_, &boundingRect );

                } else {

                    painter.drawText( rect, Qt::AlignLeft|Qt::AlignTop, value_, &boundingRect );

                }
            }

            // update rect
            rect.setRight( qMax( rect.right(), boundingRect.right() ) );
            rect.setTop( boundingRect.bottom() + spacing );
            rect.setLeft( left );

            painter.restore();

        }

        return;

    }


    //_______________________________________________________
    void SummaryDataList::paint( QPainter& painter, QRect& rect )
    {

        // calculate max extend
        int maxExtend(0);
        for( iterator iter = begin(); iter != end(); ++iter )
        {
            iter->setHorizontalOffset( iter->keyExtend( painter ) );
            maxExtend = qMax( maxExtend, iter->horizontalOffset() );
        }

        // set offsets
        for( iterator iter = begin(); iter != end(); ++iter )
        { iter->setHorizontalOffset( maxExtend - iter->horizontalOffset() ); }

        // paint
        foreach( const SummaryData& data, *this )
        { data.paint( painter, rect ); }

    }

}
