#ifndef SummaryData_h
#define SummaryData_h
// $Id: SummaryData.h,v 1.4 2013/04/29 18:27:17 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "TextFormat.h"

#include <QString>
#include <QPainter>

//! summary widgets
namespace SUMMARY {

    class SummaryData: public Counter
    {

        public:

        //! constructor
        SummaryData( const QString& key = QString(), const QString value = QString(), FORMAT::TextFormatFlags format = FORMAT::Default ):
            Counter( "SummaryData" ),
            key_( key ),
            value_( value ),
            format_( format ),
            isSeparator_( false ),
            horizontalOffset_( 0 )
        {}

        //! destructor
        virtual ~SummaryData( void )
        {}

        //! separator
        SummaryData& setIsSeparator( bool value = true )
        {
            isSeparator_ = value;
            return *this;
        }

        //! horizontal offset
        int horizontalOffset( void ) const
        { return horizontalOffset_; }

        //! horizontal offset
        SummaryData& setHorizontalOffset( int value )
        {
            horizontalOffset_ = value;
            return *this;
        }

        //! get key extend
        int keyExtend( QPainter& ) const;

        //! paint
        virtual void paint( QPainter&, QRect& ) const;

        private:

        //! key
        QString key_;

        //! value
        QString value_;

        //! format (for value)
        FORMAT::TextFormatFlags format_;

        //! separator
        bool isSeparator_;

        //! horizontal offset
        int horizontalOffset_;

    };

    //! data list
    class SummaryDataList: public QList<SummaryData>, public Counter
    {

        public:

        //! constructor
        SummaryDataList( void ):
            Counter( "SummaryDataList" )
        {}

        //! destructor
        virtual ~SummaryDataList( void )
        {}

        //! paint
        virtual void paint( QPainter&, QRect& );

    };

}

#endif
