#ifndef SummaryWidget_h
#define SummaryWidget_h
// $Id: SummaryWidget.h,v 1.35 2013/10/29 11:39:10 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Acpi.h"
#include "CpuMonitor.h"
#include "DiskMonitor.h"
#include "MemoryLoad.h"
#include "NetworkMonitor.h"
#include "TemperatureMonitor.h"
#include "MainWindow.h"

#include <QBasicTimer>
#include <QHash>
#include <QTimerEvent>
#include <QAction>
#include <QActionGroup>

//! summary widgets
namespace SUMMARY
{


    //! transparent clock widget
    class SummaryWidget: public MainWindow
    {

        //! Qt meta object declaration
        Q_OBJECT

        public:

        //! constructor
        SummaryWidget( QWidget *parent = 0 );

        //! destructor
        virtual ~SummaryWidget( void )
        {}

        protected:

        //! context menu
        virtual void _installContextMenuActions( BaseContextMenu* );

        //! adjust time
        QAction& _adjustTimeAction( void )
        { return *adjustTimeAction_; }

        //!@name event handlers
        //@{

        //! timer event, to toggle repaint
        virtual void timerEvent( QTimerEvent* event );

        //! paint event handler
        void _paint( QPaintDevice&, const QRect& );

        //@}

        protected Q_SLOTS:

        //! configuration
        virtual void _configuration( void );

        //! update configuration
        virtual void _updateConfiguration( void );

        //! adjust time
        virtual void _adjustTime( void );

        private Q_SLOTS:

        //! toggle display
        void _toggleDisplay( QAction* );

        private:

        //! install actions
        void _installActions( void );

        //! update display actions from mask
        void _updateDisplayActions( void );

        // horizontal line
        void _paintHorizontalLine( QPainter&, QRect ) const;

        //!@name sensors
        //@{

        //! battery
        ACPI::Acpi acpi_;

        //! cpu monitor
        CPU::CpuMonitor cpuMonitor_;

        //! network monitor
        NETWORK::NetworkMonitor networkMonitor_;

        //! disk load
        DISK::DiskMonitor diskMonitor_;

        //! memory load
        MEMORY::MemoryLoad memoryLoad_;

        //! temperature
        TEMPERATURE::TemperatureMonitor temperatureMonitor_;

        //@}

        //! redraw timer
        QBasicTimer timer_;

        //! temperature menu action
        QAction* temperatureMenuAction_;

        //!@name menu actions
        //@{

        //! display mode
        enum DisplayMode
        {
            HOST        = 1<<0,
            DATE        = 1<<1,
            TIME        = 1<<2,
            CPU         = 1<<3,
            MEMORY      = 1<<4,
            DISK        = 1<<5,
            NETWORK     = 1<<6,
            TEMPERATURE = 1<<7,
            ACPI = 1<<8,
            ALL = HOST|DATE|TIME|CPU|MEMORY|DISK|NETWORK|TEMPERATURE|ACPI
        };

        /*! maps an action and the corresponding bit mask */
        // typedef QHash<QAction*, DisplayMode> DisplayActionMap;
        typedef QHash<QAction*, DisplayMode> DisplayActionMap;

        //! display actions
        DisplayActionMap displayActions_;

        // display action group
        QActionGroup* displayActionGroup_;

        //! adjust time
        QAction* adjustTimeAction_;

        //!@name properties
        //@{

        //! display mask
        unsigned int displayMask_;

        //! time delay
        int delay_;

        //! application hostname
        QString hostName_;

        //! refresh time
        int refresh_;

        //@}

    };

};

#endif
