
// $Id: TemperatureConfigurationDialog.cpp,v 1.29 2014/01/10 12:14:16 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TemperatureConfigurationDialog.h"
#include "TemperatureConfigurationDialog.moc"

#include "GridLayout.h"
#include "IconEngine.h"
#include "Icons.h"
#include "OptionCheckBox.h"
#include "OptionColorDisplay.h"
#include "OptionSlider.h"
#include "OptionSpinBox.h"
#include "OptionBrowsedLineEditor.h"

#include <QGroupBox>
#include <QLabel>
#include <QLayout>

namespace TEMPERATURE
{

    //_________________________________________________________
    TemperatureConfigurationDialog::TemperatureConfigurationDialog( QWidget* parent ):
        ConfigurationDialog( parent )
    {

        Debug::Throw( "TemperatureConfigurationDialog::TemperatureConfigurationDialog.\n" );
        setWindowTitle( "Configuration - Temperature Monitor" );

        // generic widgets
        QWidget* page;
        QWidget *box;
        OptionColorDisplay *colorDisplay;
        OptionCheckBox* checkbox;
        OptionSlider* slider;

        page = &addPage( IconEngine::get( ICONS::PREFERENCE_APPEARANCE), tr( "Appearance" ), tr( "Window appearance and colors" ) );
        page->layout()->addWidget( box = new QWidget( page ));

        QVBoxLayout* boxLayout( new QVBoxLayout() );
        boxLayout->setSpacing(5);
        boxLayout->setMargin(0);
        box->setLayout( boxLayout );

        GridLayout* gridLayout = new GridLayout();
        gridLayout->setSpacing(5);
        gridLayout->setMargin(0);
        gridLayout->setMaxCount( 2 );
        gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
        boxLayout->addLayout( gridLayout );

        gridLayout->addWidget( new QLabel( tr( "Color:" ), box ) );
        gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "TEMPERATURE_COLOR" ) );
        addOptionWidget( colorDisplay );

        // intensity
        gridLayout->addWidget( new QLabel( tr( "Intensity:" ), this ) );
        gridLayout->addWidget( slider = new OptionSlider( this, "TRANSPARENCY_BACKGROUND_INTENSITY" ) );
        slider->setScale( 1.0/2.55 );
        slider->setRange( 0, 100 );
        addOptionWidget( slider );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Use gradient" ), box, "TRANSPARENCY_USE_GRADIENT" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Show temperature" ), box, "SHOW_LOAD" ) );
        checkbox->setToolTip( tr( "Show/hide cpu load percentage" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox(  tr( "Show hostname" ), box, "SHOW_HOST" ) );
        checkbox->setToolTip( tr( "Show/hide host name" ) );
        addOptionWidget( checkbox );

        // Unsorted
        page = &addPage( IconEngine::get( ICONS::PREFERENCE_UNSORTED ), tr( "Unsorted" ), tr( "Additional unsorted settings" ) );
        page->layout()->addWidget( box = new QWidget( page ) );
        boxLayout = new QVBoxLayout();
        boxLayout->setSpacing(5);
        boxLayout->setMargin(0);
        box->setLayout( boxLayout );

        boxLayout->addWidget( checkbox = new OptionCheckBox(  tr( "Use lm-sensors" ), box, "USE_LM_SENSORS" ) );
        checkbox->setToolTip( tr( "Use lm-sensors to get temperatures" ) );
        checkbox->setChecked( true );
        addOptionWidget( checkbox );

        gridLayout = new GridLayout();
        gridLayout->setSpacing(5);
        gridLayout->setMargin(0);
        gridLayout->setMaxCount( 2 );
        boxLayout->addLayout( gridLayout );

        QLabel* label;
        OptionBrowsedLineEditor* editor;
        gridLayout->addWidget( label = new QLabel( tr( "Lm-sensors command:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "LM_SENSORS" ) );
        addOptionWidget( editor );
        label->setBuddy( editor );
        label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);

        connect( checkbox, SIGNAL(toggled(bool)), editor, SLOT(setEnabled(bool)) );

        gridLayout->addWidget( label = new QLabel( tr( "ACPI file:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "ACPI_FILE" ) );
        addOptionWidget( editor );
        editor->setEnabled( false );
        label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
        label->setBuddy( editor );
        connect( checkbox, SIGNAL(toggled(bool)), editor, SLOT(setDisabled(bool)) );

        OptionSpinBox* spinbox;
        gridLayout->addWidget( label = new QLabel( tr( "Refresh interval:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "REFRESH_RATE" ) );
        spinbox->setSuffix( tr( "s" ) );
        spinbox->setMinimum( 1 );
        spinbox->setToolTip( tr( "Time interval (seconds) between two refresh" ) );
        addOptionWidget( spinbox );
        label->setBuddy( spinbox );
        label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);

        gridLayout->addWidget( label = new QLabel( tr( "Number of samples:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "SAMPLES" ) );
        spinbox->setMinimum( 1 );
        spinbox->setToolTip( tr( "Number of samples averaged for each measurement" ) );
        addOptionWidget( spinbox );
        label->setBuddy( spinbox );
        label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);

        read();

    }

}
