// $Id: TemperatureMenu.cpp,v 1.5 2013/11/15 14:50:40 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TemperatureMenu.h"
#include "TemperatureMenu.moc"
#include "Debug.h"
#include "IconEngine.h"

namespace TEMPERATURE
{
    //_____________________________________________________
    TemperatureMenu::TemperatureMenu( const QString& name, QWidget* parent ):
        QMenu( name, parent ),
        Counter( "TemperatureMenu" )
    {

        Debug::Throw( "TemperatureMenu::TemperatureMenu.\n" );

        connect( this, SIGNAL(triggered(QAction*)), SLOT(_select(QAction*)) );
        connect( this, SIGNAL(aboutToShow()), SLOT(_update()) );

        actionGroup_ = new QActionGroup( this );
        actionGroup_->setExclusive( true );

    }

    //_____________________________________________________
    void TemperatureMenu::_select( QAction* action )
    {

        Debug::Throw( "TemperatureMenu::_select.\n" );
        ActionMap::const_iterator iter( actions_.find( action ) );
        if( iter != actions_.end() )
        {
            device_ = iter.value();
            emit deviceSelected( device_ );
        }

        return;
    }

    //_____________________________________________________
    void TemperatureMenu::_update( void )
    {
        Debug::Throw( "TemperatureMenu::_update.\n" );

        // clear
        clear();
        actions_.clear();

        if( devices_.empty() ) devices_.insert( device_ );
        for( Temperature::ProbeNames::iterator iter = devices_.begin(); iter != devices_.end(); ++iter )
        {
            QAction* action = addAction( *iter );
            actionGroup_->addAction( action );
            action->setCheckable( true );
            action->setChecked( device_ == *iter );

            actions_.insert( action, *iter );

        }

        return;

    }
}
