// $Id: TemperatureMonitor.cpp,v 1.3 2013/11/15 14:50:40 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TemperatureMonitor.h"
#include "TemperatureMonitor.moc"
#include "Debug.h"
#include "Singleton.h"
#include "XmlOptions.h"

namespace TEMPERATURE
{

    //_____________________________________________
    TemperatureMonitor::TemperatureMonitor( QObject* parent ):
        QObject( parent ),
        Counter( "TEMPERATURE::TemperatureMonitor" ),
        temperatureMenu_( 0 ),
        device_( "temperature" )
    {

        // temperature menu
        temperatureMenu_ = new TemperatureMenu();
        connect( temperatureMenu_, SIGNAL(deviceSelected(QString)), SLOT(_selectDevice(QString)) );
        if( temperature_.useSensors() ) temperatureMenu_->setDevice( device_ );

        connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
        _updateConfiguration();

    }

    //______________________________________________________________________
    void TemperatureMonitor::_selectDevice( QString device )
    {
        device_ = device;
        XmlOptions::get().set( "PROBE_NAME", device_ );
    }

    //__________________________________________________________
    void TemperatureMonitor::_updateConfiguration( void )
    {
        Debug::Throw( "TEMPERATURE::TemperatureMonitor::_updateConfiguration.\n" );

        // sensors
        temperature_.setUseSensors( XmlOptions::get().get<bool>( "USE_LM_SENSORS" ) );

        // device, probe name and temperature menu
        if( temperature_.useSensors() && XmlOptions::get().contains( "PROBE_NAME" ) )
        {

            device_ = XmlOptions::get().raw( "PROBE_NAME" );
            temperatureMenu_->setDevice( device_ );

        }

        // samples
        temperature_.setSampleSize( XmlOptions::get().get<int>( "SAMPLES" ) );

    }

}
